@@ -6,16 +6,19 @@ from moderator.models import ClassifiedComment
 
 class Command(BaseCommand):
     help = 'Classifies comments as either spam or '\
-            'ham using Bayesian inference.'
+           'ham using Bayesian inference.'
 
     def handle(self, *args, **options):
         self.stdout.write('Classifying, please wait...\n')
-        classified_comments = ClassifiedComment.objects.all()
-        unclassified_comments = Comment.objects.exclude(
-            pk__in=[classified_comment.pk \
+        classified_comments = ClassifiedComment.objects.filter(
+            cls__in=['spam', 'ham']
+        )
+        unsure_comments = Comment.objects.exclude(
+            pk__in=[classified_comment.pk
                     for classified_comment in classified_comments]
         )
-        for comment in unclassified_comments:
-            cls = utils.get_class(comment)
-            ClassifiedComment.objects.create(comment=comment, cls=cls)
-            self.stdout.write('Classified %s as %s\n' % (comment, cls))
+
+        for comment in unsure_comments:
+            classified_comment = utils.classify_comment(comment)
+            self.stdout.write('Classified %s as %s\n'
+                              % (comment, classified_comment.cls))
